<p align="center">
  <img src="./docs/bone.png" alt="bone" width="160px" height="160px">
</p>

<h2 align="center">bone: the simple python web framework</h2>
<p align="center">
<img src="https://img.shields.io/pypi/l/bone?label=license" alt="License"/>
<a href="https://pypi.org/project/bone/"><img alt="PyPI" src="https://img.shields.io/pypi/v/bone"></a>
<img src="https://img.shields.io/github/repo-size/qe/bone?label=repo size" alt="GitHub Repo Size"/>
<img src="https://img.shields.io/github/languages/code-size/qe/bone?label=code size" alt="GitHub Code Size (bytes)"/>
<img src="https://img.shields.io/tokei/lines/github/qe/bone?label=lines of code" alt="Total Lines of Code"/>
</p>

<p align="center">
  <a href="https://github.com/qe/bone/archive/refs/heads/master.zip">Download</a>
  ·
  <a href="https://github.com/qe/bone/issues/new?template=bug_report.md">Report bug</a>
  <br>
  <br>
</p>

> “Our life is frittered away by detail. Simplify, simplify.” 
>
>—Henry David Thoreau


